@@ -13,7 +13,7 @@ our @ISA = 'Regexp';
 
 BEGIN
 {
-  our $VERSION = '0.008'; # VERSION
+  our $VERSION = '0.009'; # VERSION
     XSLoader::load __PACKAGE__, $VERSION;
 }
 
@@ -26,10 +26,10 @@ sub import
     if (@_) {
       my %args = @_;
       if (exists $args{'-debug'}) {
-        $^H{__PACKAGE__ . '::debug'} = $args{'-debug'};
+        $^H{__PACKAGE__ . '/debug'} = $args{'-debug'};
       }
       if (exists $args{'-syntax'}) {
-        $^H{__PACKAGE__ . '::syntax'} = $args{'-syntax'};
+        $^H{__PACKAGE__ . '/syntax'} = $args{'-syntax'};
       }
     }
 
@@ -59,7 +59,7 @@ re::engine::GNU - GNU Regular Expression Engine
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
